
	/* Center for American Progress - Higher Education 
		
		Replication Code for: 
		"Gone and Not Forgiven: Exploring the Loan 
			Forgiveness Costs of Gainful Employment Programs"
		
		Authors: Ben Miller, CJ Libassi
		Last Edit: 3.29.17
		
		
		**CODE FOR UNDERGRADUATES**
	*/
	
	*Next do GE data
	use "${ge_data}CAP_ge_base_data.dta", clear 
	
	describe 
	
	*Build Out Model
	
		/* 
			Assumptions from FSA: 
				-Paying continuously
				-5% growth in income each year 
				-Family size will remain the same
				-Poverty guidelines increase based on CBO's estimation of inflation
				-Stable interest rate 
		*/
	
	*Some cleanup 
	destring level_code, replace 
	
	label define level_code 1 "Undergrad Cert" 2 "Associates Degree" 3 "Bachelor's Degree" ///
				4 "Post-Baccalaureate Cert" 5 "Master's Degree" 6 "Doctoral Degree" ///
				7 "First Professional Degree" 8 "Graduate Certificate" 
				
	label values level_code level_code
	
	drop if inlist(level_code, 5, 6, 7, 8)
	
	*label values level_code level_code 
	
	**** Calculate Standard 10yr payment 
	
	*Backing Out Total Loan Balance from Annual Payments
		* i = annual interest rate
		* n = number of years
		* t = number of payments per year 
		* p = annual payment 
	
	
	*Step 1: Calculate Total Loan Balance of loan, drop those without any starting principal balance 
	
		/* 
			We do this so that we can find the 
			standard 10yr payment & calculate forgiveness
			
			Formula is: 
			
					1-(1+(Interest Rate/Payments per year)^-(Number of years in amortization that produced payment*Payments per year)
				x   (Annual loan payment/Payments per year)/(Interest rate/Payments per year)
				_____________________________________________________________________________________________________________________
							Principal Balance
		*/
		
	gen principal_balance =  .
	
		replace principal_balance = ((1-(1+(.068/12))^-(10*12))*(debt_to_earn_disc_num/12))/(.068/12) if (level_code==1 | level_code==2) & debt_to_earn_disc_num>0 
		replace principal_balance = ((1-(1+(.068/12))^-(15*12))*(debt_to_earn_disc_num/12))/(.068/12) if (level_code==3 | level_code==4 | level_code==5) & debt_to_earn_disc_num>0 
		replace principal_balance = ((1-(1+(.068/12))^-(20*12))*(debt_to_earn_disc_num/12))/(.068/12) if (level_code==6 | level_code==7 | level_code==8) & debt_to_earn_disc_num>0 
	
	*Restrict to only schools with principal balance greater than 0 
	*drop if principal_balance==0 | missing(principal_balance) 
	
	*Step 2: Calculate 10-yr standard payment for each program
				* A = P*((r(1+r)^n)/((1+r)^n)-1)
				
	gen standard_payment = principal_balance*((.00566667*(1+.00566667)^120))/(((1+.00566667)^120)-1)
		
		*Replace if payment isn't at least the minimum payment of $50
		replace standard_payment = 50 if standard_payment>0 & standard_payment<50 & !missing(standard_payment) 
			
		*Figure out the annual payment
		gen annual_payment = standard_payment*12 
			
			/*Replace annual payment with the principal balance if the minimum 
				annual payment (12*50=$600) is greater than original principal 
				balance	*/
			replace annual_payment = principal_balance if principal_balance<600 

	
	*Step 3: Calculate Discretionary Income in base year (2015), to serve as basis for PAYE payment calc
		
		*Earnings in 2014 for 2015 payment year  
		gen earnings_year_3 = max(med_earnings, mean_earnings) 
		gen disc_med_earn_year_3 = .
		
			local fpl_150 = 11770*1.5 
				replace disc_med_earn_year_3 = 0 if earnings <= `fpl_150'
				replace disc_med_earn_year_3 = earnings - `fpl_150' if earnings > `fpl_150'
				
		*Set Earnings Appreciation Rate
		local earn_grow = .05
		local earn_grow_factor = 1+`earn_grow'
		
	
	*Step 4: Calculation Income In Years Outside the Base Year
	
		/* 
			Work backward and forward from base year, assuming a 5% growth in 
			income each year, which is what the FSA Repayment calculator 
			assumes. We make the assumption that all repayers enter repayment 
			in January 2013. 
		*/
		
		
		*First moving backward 
		
		*2013 Earnings for 2014 payment year
		gen earnings_year_2 = earnings_year_3/`earn_grow_factor'
		
			local fpl_150 = 11670*1.5 
		gen disc_med_earn_year_2 = .
			replace disc_med_earn_year_2 = 0 if earnings_year_2 <= `fpl_150'
			replace disc_med_earn_year_2 = earnings_year_2 - `fpl_150' if earnings_year_2 > `fpl_150'	

		*2012 Earnings for 2013 payment year
		gen earnings_year_1 = earnings_year_2/`earn_grow_factor'
		
			local fpl_150 = 11490*1.5 
		gen disc_med_earn_year_1 = .
			replace disc_med_earn_year_1 = 0 if earnings_year_1 <= `fpl_150'
			replace disc_med_earn_year_1 = earnings_year_1 - `fpl_150' if earnings_year_1 > `fpl_150'	

	
		*Now Go Forward in Time with Actual Poverty Level for Years that we have it for
		
		*2015 earnings for 2016 payment year (real poverty level)
		gen earnings_year_4 = earnings_year_3*`earn_grow_factor'
		
			local fpl_150 = 11880*1.5 
		gen disc_med_earn_year_4 = .
				replace disc_med_earn_year_4 = 0 if earnings_year_4 <= `fpl_150'
				replace disc_med_earn_year_4 = earnings_year_4 - `fpl_150' if earnings_year_4 > `fpl_150'
				
		*2016 earning for 2017 payment year (real poverty level)
		gen earnings_year_5 = earnings_year_4*`earn_grow_factor'
		
			local fpl_150 = 12060*1.5 
		gen disc_med_earn_year_5 = .
				replace disc_med_earn_year_5 = 0 if earnings_year_5 <= `fpl_150'
				replace disc_med_earn_year_5 = earnings_year_5 - `fpl_150' if earnings_year_5 > `fpl_150'
				
		/*Now loop through going forward, increasing income by 5% and inflating poverty level
				by 2% every year */
		
		local pov_level = 12060 
		
		forvalues i = 6/20{ 
		
			local pov_level = `pov_level'*1.02 
			
				di "Poverty level is `pov_level'" 
		
			local last_year= `i'-1
			
			gen earnings_year_`i' = earnings_year_`last_year'*`earn_grow_factor'
			
				local fpl_150 = `pov_level'*1.5 
			gen disc_med_earn_year_`i' = .
				replace disc_med_earn_year_`i' = 0 if earnings_year_`i' <= `fpl_150'
				replace disc_med_earn_year_`i' = earnings_year_`i' - `fpl_150' if earnings_year_`i' > `fpl_150'	
			}
	
		*Determine if there is a partial financial hardship by comparing standard payment to 10% of Discretionary Income
		*Set blank variable
		gen interest_month_1_year_1 = 0
				
			*Generate interest acruals for 31 day months
			replace interest_month_1_year_1 = principal_balance*31*(.068/365) ///
					if 1==1 | 1==3 | 1==5 | 1==7 | ///
							1==8 | 1==10 | 1==12  
								
			*Generate interest acruals for 30 day months			
			replace interest_month_1_year_1 = principal_balance*30*(.068/365) ///
						if 1==4 | 1==6 | 1==9 | 1==11 
			
			*Generate interest acruals for February
			replace interest_month_1_year_1 = principal_balance*28*(.068/365) ///
						if 1==2 

			*Add interest for this month to interest principal 
			egen amount_owed_1_year_1 = rowtotal(interest_month_1_year_1 principal_balance)
				
			*Calculate 10% of discretionary income, divide by 12
			gen ten_perc_1_year_1 = (disc_med_earn_year_1*.1)/12
					
			*Calculate Repaye Payment as minimum of ten percent and amount left to pay
			gen repaye_payment_month_1_year_1 = min(ten_perc_1_year_1, amount_owed_1_year_1) 
				replace repaye_payment_month_1_year_1=. if principal_balance==.
			
			*Calculate Repaye Payment as max of amoritzed payment and $50, which is the min payment
			gen standard_paymennt_month_1_year_1 = max(50, standard_payment) 
				
				*Create a fix if the outstanding balance is less than $50
				replace standard_paymennt_month_1_year_1 = principal_balance if principal_balance<50
		
			*Create an indicator for partial financial hardship if REPAYE payment would be lower than standard payment
			gen part_fin_hard = repaye_payment_month_1_year_1<standard_paymennt_month_1_year_1 ///
					& !missing(standard_paymennt_month_1_year_1) & !missing(principal_balance)  
			
			*Drop all of these variables so the loop doesn't get screwed up 
			drop interest_month_1_year_1 amount_owed_1_year_1 ten_perc_1_year_1 ///
					repaye_payment_month_1_year_1 standard_paymennt_month_1_year_1 
			
			
	
	/*Step 5: With Loops 
	
			a) Calculate Pay-as-you-earn payment for each year 
			b) Calculate monthly interest accruals
			c) Calculate portion of actual payment that is interest & principal
			d) Calculate interest running accumulation across months 
			e) Calculate monthly principal paydown
	
	*/
		*Set up running calculation of the principal balance & accumulating interest
		gen rp_running_princ_bal = principal_balance 
		gen std_running_princ_bal = principal_balance 
		gen act_running_princ_bal = principal_balance 
	
		gen rp_accum_excess_interest = 0 
		gen std_accum_excess_interest = 0 
		gen act_accum_excess_interest = 0 
	
		*Loop through years
		forvalues year = 1/20{ 
		
			*Loop through months
			forvalues month = 1/12{
		
				*Check Principal Balance at beginning of month
				gen rp_running_princ_bal_`month'_`year' = rp_running_princ_bal
				gen std_running_princ_bal_`month'_`year' = std_running_princ_bal
				gen act_running_princ_bal_`month'_`year' = act_running_princ_bal
				
				*A) Calculate Interest Amount Acrrued in This Month
				
				*REPAYE 
				*Set blank variable
				gen rp_interest_month_`month'_year_`year' = 0
				
					*Generate interest acruals for 31 day months
					replace rp_interest_month_`month'_year_`year' = rp_running_princ_bal*31*(.068/365) ///
							if `month'==1 | `month'==3 | `month'==5 | `month'==7 | ///
								`month'==8 | `month'==10 | `month'==12  
								
					*Generate interest acruals for 30 day months			
					replace rp_interest_month_`month'_year_`year' = rp_running_princ_bal*30*(.068/365) ///
							if `month'==4 | `month'==6 | `month'==9 | `month'==11 
			
					*Generate interest acruals for February
					replace rp_interest_month_`month'_year_`year' = rp_running_princ_bal*28*(.068/365) ///
							if `month'==2 
							
				*STD 
				*Set blank variable
				gen std_interest_month_`month'_year_`year' = 0
				
					*Generate interest acruals for 31 day months
					replace std_interest_month_`month'_year_`year' = std_running_princ_bal*31*(.068/365) ///
							if `month'==1 | `month'==3 | `month'==5 | `month'==7 | ///
								`month'==8 | `month'==10 | `month'==12  
								
					*Generate interest acruals for 30 day months			
					replace std_interest_month_`month'_year_`year' = std_running_princ_bal*30*(.068/365) ///
							if `month'==4 | `month'==6 | `month'==9 | `month'==11 
			
					*Generate interest acruals for February
					replace std_interest_month_`month'_year_`year' = std_running_princ_bal*28*(.068/365) ///
							if `month'==2 
							
				*Actual 
				*Set blank variable
				gen act_interest_month_`month'_year_`year' = 0
				
					*Generate interest acruals for 31 day months
					replace act_interest_month_`month'_year_`year' = act_running_princ_bal*31*(.068/365) ///
							if `month'==1 | `month'==3 | `month'==5 | `month'==7 | ///
								`month'==8 | `month'==10 | `month'==12  
								
					*Generate interest acruals for 30 day months			
					replace act_interest_month_`month'_year_`year' = act_running_princ_bal*30*(.068/365) ///
							if `month'==4 | `month'==6 | `month'==9 | `month'==11 
			
					*Generate interest acruals for February
					replace act_interest_month_`month'_year_`year' = act_running_princ_bal*28*(.068/365) ///
							if `month'==2 
							
				*B) Adjust Accumulated Interest So All Unpaid Interest Is Lumped into One Amount that must be paid off before touching principal
				
					*REPAYE
					*Add this month's interest to the running accumulated interest 
					egen rp_accum_int_month_`month'_year_`year' = rowtotal(rp_accum_excess_interest rp_interest_month_`month'_year_`year')
					
					replace rp_accum_excess_interest = rp_accum_int_month_`month'_year_`year'
					
					*STD
					*Add this month's interest to the running accumulated interest 
					egen std_accum_int_month_`month'_year_`year' = rowtotal(std_accum_excess_interest std_interest_month_`month'_year_`year')
					
					replace std_accum_excess_interest = std_accum_int_month_`month'_year_`year'
					
					*Actual
					*Add this month's interest to the running accumulated interest 
					egen act_accum_int_month_`month'_year_`year' = rowtotal(act_accum_excess_interest act_interest_month_`month'_year_`year')
					
					replace act_accum_excess_interest = act_accum_int_month_`month'_year_`year'
					
				*C) Calculate a total amount left to be paid (principal & interest) that cannot be exceded with any payment
				
					*REPAYE
					egen rp_total_balance_`month'_`year' = rowtotal(rp_running_princ_bal rp_accum_excess_interest)
					
					*STD
					egen std_total_balance_`month'_`year' = rowtotal(std_running_princ_bal std_accum_excess_interest)
					

				*D) Calculate REPAYE Payment and Breakdown 
				
					*REPAYE amount = minimum of 10% of discretionary income in that year or total balance as of that month
				
					*Calculate 10% of discretionary income, divide by 12
					gen ten_perc_`month'_year_`year' = (disc_med_earn_year_`year'*.1)/12
					
					*Calculate REPAYE Payment as minimum of ten percent and amount left to pay
					gen repaye_payment_month_`month'_year_`year' = min(ten_perc_`month'_year_`year', rp_total_balance_`month'_`year')  
					
					*REPAYE payment breakdown:
						
					*First calculate interest part by taking the minimum of the outstanding interest and the REPAYE payment
					gen repaye_int_pt_`month'_`year' = min(rp_accum_excess_interest, repaye_payment_month_`month'_year_`year')
						
					*Then calculate principal part by calculating the remaining payment not going toward interest
					gen repaye_minus_int_`month'_`year' = repaye_payment_month_`month'_year_`year'-rp_interest_month_`month'_year_`year'
					gen repaye_princ_pt_`month'_`year' = max(repaye_minus_int_`month'_`year', 0)
						
					*Then calculate the net change in interest as interest accumulated less interested paid 
					gen rp_interest_change_`month'_`year' = -1*(repaye_int_pt_`month'_`year')+(rp_interest_month_`month'_year_`year'-repaye_int_pt_`month'_`year')
					
						*Make adjustment for the REPAYE interest subsidy
						replace  rp_interest_change_`month'_`year' =  0 if `year'<4 & rp_interest_change_`month'_`year'>0
							
						replace  rp_interest_change_`month'_`year' =  rp_interest_change_`month'_`year'/2 if `year'>3 & rp_interest_change_`month'_`year'>0 & !missing(rp_interest_change_`month'_`year')
						
						
						
				*E) Calculate Standard Payment and Breakdown 
					
					*Calculate final standard payment as minimum of standard payment and amount left to pay 
					gen std_payment_`month'_`year' = min(standard_payment, std_total_balance_`month'_`year') 
					
					*First calculate interest part by taking the minimum of the outstanding interest and the standard payment
					gen std_int_pt_`month'_`year' = min(std_interest_month_`month'_year_`year', std_payment_`month'_`year')
						
					*Then calculate principal part by calculating the remaining payment not going toward interest
					gen std_minus_int_`month'_`year' = std_payment_`month'_`year'-std_interest_month_`month'_year_`year'
					gen std_princ_pt_`month'_`year' = max(std_minus_int_`month'_`year', 0)
					
					*Then calculate the net change in interest as interest accumulated less interested paid (in standard situation, interest never goes unpaid)
					gen std_interest_change_`month'_`year' = -1*(std_int_pt_`month'_`year')+(std_interest_month_`month'_year_`year'-std_int_pt_`month'_`year')
									
					
				*F) Calculate True Payment & True Payment Parts & True Interest Change
				
					*If there's a hardship, assign the REPAYE payment, if not then standard payment
					gen actual_payment_`month'_`year' = std_payment_`month'_`year' if part_fin_hard==0
					replace actual_payment_`month'_`year' = repaye_payment_month_`month'_year_`year' if part_fin_hard
					
					*If there's a hardship, assign REPAYE interest part, if not standard interest part 
					gen actual_int_pt_`month'_`year' = std_int_pt_`month'_`year' if part_fin_hard==0 
					replace actual_int_pt_`month'_`year' = repaye_int_pt_`month'_`year' if part_fin_hard 
				
					*If there's a hardship, assign REPAYE principal part, if not standard principal part
					gen actual_princ_pt_`month'_`year' = std_princ_pt_`month'_`year' if part_fin_hard==0 
					replace actual_princ_pt_`month'_`year' = repaye_princ_pt_`month'_`year' if part_fin_hard  
				
					*If there's a hardship, assign REPAYE interest change, otherwise assign standard interest change 
					gen actual_interest_change_`month'_`year' = std_interest_change_`month'_`year' if part_fin_hard==0 
					replace actual_interest_change_`month'_`year' = rp_interest_change_`month'_`year' if part_fin_hard
					
					*Capture interest forgiven at this moment
					gen act_interest_forgiven_`month'_`year' = actual_interest_change_`month'_`year' if `year'<4 & rp_interest_change_`month'_`year'>0 & part_fin_hard
					replace act_interest_forgiven_`month'_`year' = actual_interest_change_`month'_`year'/2 if `year'>3 & rp_interest_change_`month'_`year'>0 & !missing(rp_interest_change_`month'_`year')  & part_fin_hard
							
					
					**** Build in a check to make sure payment parts add up to full payment
					gen pts_not_equal_flag_`month'_`year' = round(actual_payment_`month'_`year')!=round(actual_int_pt_`month'_`year'+actual_princ_pt_`month'_`year')
					
				*G) Draw down the prinicipal & interest balances separately for REPAYE, Standard & Actual 
				
					*REPAYE 
					
					*Principal draw down. Take principal amount and subtract out principal part of payment
					replace rp_running_princ_bal  = rp_running_princ_bal-repaye_princ_pt_`month'_`year'
					
						*Store the principal balance after payment 
						gen rp_post_rprinc_`month'_`year' = rp_running_princ_bal 
					
					*Interest draw down. Take accumulated interest amount and add net interest change
					replace rp_accum_excess_interest = rp_accum_excess_interest+rp_interest_change_`month'_`year'
					
						*Store the interest balance after payment 
						gen rp_post_aint_month_`month'_year_`year' = rp_accum_excess_interest
						
						
						
					*Standard
						
					*Principal draw down. Take principal amount and subtract out principal part of payment
					replace std_running_princ_bal  = std_running_princ_bal-std_princ_pt_`month'_`year'
					
						*Store the principal balance after payment 
						gen std_post_rprinc_`month'_`year' = std_running_princ_bal 
					
					*Interest draw down. Take accumulated interest amount and add net interest change
					replace std_accum_excess_interest = std_accum_excess_interest+std_interest_change_`month'_`year'
					
						*Store the interest balance after payment 
						gen std_post_aint_month_`month'_year_`year' = std_accum_excess_interest
						
						
						
					*Actual
					
					*Principal draw down. Take principal amount and subtract out principal part of payment
					replace act_running_princ_bal  = act_running_princ_bal-actual_princ_pt_`month'_`year'
					
						*Store the principal balance after payment 
						gen act_post_rprinc_`month'_`year' = act_running_princ_bal 
					
					*Interest draw down. Take accumulated interest amount and add net interest change
					replace act_accum_excess_interest = act_accum_excess_interest+actual_interest_change_`month'_`year'
					
						*Store the interest balance after payment 
						gen act_post_aint_month_`month'_year_`year' = act_accum_excess_interest
				
				
				
			
			}
		}


	*Clean up the dataset a bit & do a reshape to set it up to become a panel

		
		*Drop labels
		label drop level_code
		
		*Create a temp variable to move the codes
		gen test = level_code 
		
		*Destring the new variable
		tostring test, replace 
		
		*Drop the original
		drop level_code 
		
		*Turn temp variable into a string with a zero at the front
		replace test= "0"+test
		
		*Rename it to level code
		rename test level_code 
		
		*Reshape to long by year, leaving months wide
		reshape long earnings_year_ disc_med_earn_year_ ///
			 rp_running_princ_bal_1_ ///
			 std_running_princ_bal_1_ act_running_princ_bal_1_ rp_interest_month_1_year_ /// 
			 std_interest_month_1_year_  act_interest_month_1_year_ rp_accum_int_month_1_year_ ///
			 std_accum_int_month_1_year_ act_accum_int_month_1_year_ rp_total_balance_1_ ///
			 std_total_balance_1_ ten_perc_1_year_ repaye_payment_month_1_year_ repaye_int_pt_1_ ///
			 repaye_minus_int_1_ repaye_princ_pt_1_ rp_interest_change_1_ std_payment_1_ ///
			 std_int_pt_1_ std_minus_int_1_ std_princ_pt_1_ std_interest_change_1_ ///
			 actual_payment_1_ actual_int_pt_1_ actual_princ_pt_1_ actual_interest_change_1_ ///
			 pts_not_equal_flag_1_ rp_post_rprinc_1_ rp_post_aint_month_1_year_ ///
			 std_post_rprinc_1_ std_post_aint_month_1_year_ act_post_rprinc_1_ ///
			 act_post_aint_month_1_year_ act_interest_forgiven_1_ ///
			 rp_running_princ_bal_2_ ///
			 std_running_princ_bal_2_ act_running_princ_bal_2_ rp_interest_month_2_year_ /// 
			 std_interest_month_2_year_  act_interest_month_2_year_ rp_accum_int_month_2_year_ ///
			 std_accum_int_month_2_year_ act_accum_int_month_2_year_ rp_total_balance_2_ ///
			 std_total_balance_2_ ten_perc_2_year_ repaye_payment_month_2_year_ repaye_int_pt_2_ ///
			 repaye_minus_int_2_ repaye_princ_pt_2_ rp_interest_change_2_ std_payment_2_ ///
			 std_int_pt_2_ std_minus_int_2_ std_princ_pt_2_ std_interest_change_2_ ///
			 actual_payment_2_ actual_int_pt_2_ actual_princ_pt_2_ actual_interest_change_2_ ///
			 pts_not_equal_flag_2_ rp_post_rprinc_2_ rp_post_aint_month_2_year_ ///
			 std_post_rprinc_2_ std_post_aint_month_2_year_ act_post_rprinc_2_ ///
			 act_post_aint_month_2_year_ act_interest_forgiven_2_ ///
			 rp_running_princ_bal_3_ ///
			 std_running_princ_bal_3_ act_running_princ_bal_3_ rp_interest_month_3_year_ /// 
			 std_interest_month_3_year_  act_interest_month_3_year_ rp_accum_int_month_3_year_ ///
			 std_accum_int_month_3_year_ act_accum_int_month_3_year_ rp_total_balance_3_ ///
			 std_total_balance_3_ ten_perc_3_year_ repaye_payment_month_3_year_ repaye_int_pt_3_ ///
			 repaye_minus_int_3_ repaye_princ_pt_3_ rp_interest_change_3_ std_payment_3_ ///
			 std_int_pt_3_ std_minus_int_3_ std_princ_pt_3_ std_interest_change_3_ ///
			 actual_payment_3_ actual_int_pt_3_ actual_princ_pt_3_ actual_interest_change_3_ ///
			 pts_not_equal_flag_3_ rp_post_rprinc_3_ rp_post_aint_month_3_year_ ///
			 std_post_rprinc_3_ std_post_aint_month_3_year_ act_post_rprinc_3_ ///
			 act_post_aint_month_3_year_ act_interest_forgiven_3_ ///
			 rp_running_princ_bal_4_ ///
			 std_running_princ_bal_4_ act_running_princ_bal_4_ rp_interest_month_4_year_ /// 
			 std_interest_month_4_year_  act_interest_month_4_year_ rp_accum_int_month_4_year_ ///
			 std_accum_int_month_4_year_ act_accum_int_month_4_year_ rp_total_balance_4_ ///
			 std_total_balance_4_ ten_perc_4_year_ repaye_payment_month_4_year_ repaye_int_pt_4_ ///
			 repaye_minus_int_4_ repaye_princ_pt_4_ rp_interest_change_4_ std_payment_4_ ///
			 std_int_pt_4_ std_minus_int_4_ std_princ_pt_4_ std_interest_change_4_ ///
			 actual_payment_4_ actual_int_pt_4_ actual_princ_pt_4_ actual_interest_change_4_ ///
			 pts_not_equal_flag_4_ rp_post_rprinc_4_ rp_post_aint_month_4_year_ ///
			 std_post_rprinc_4_ std_post_aint_month_4_year_ act_post_rprinc_4_ ///
			 act_post_aint_month_4_year_ act_interest_forgiven_4_ ///
			 rp_running_princ_bal_5_ ///
			 std_running_princ_bal_5_ act_running_princ_bal_5_ rp_interest_month_5_year_ /// 
			 std_interest_month_5_year_  act_interest_month_5_year_ rp_accum_int_month_5_year_ ///
			 std_accum_int_month_5_year_ act_accum_int_month_5_year_ rp_total_balance_5_ ///
			 std_total_balance_5_ ten_perc_5_year_ repaye_payment_month_5_year_ repaye_int_pt_5_ ///
			 repaye_minus_int_5_ repaye_princ_pt_5_ rp_interest_change_5_ std_payment_5_ ///
			 std_int_pt_5_ std_minus_int_5_ std_princ_pt_5_ std_interest_change_5_ ///
			 actual_payment_5_ actual_int_pt_5_ actual_princ_pt_5_ actual_interest_change_5_ ///
			 pts_not_equal_flag_5_ rp_post_rprinc_5_ rp_post_aint_month_5_year_ ///
			 std_post_rprinc_5_ std_post_aint_month_5_year_ act_post_rprinc_5_ ///
			 act_post_aint_month_5_year_ act_interest_forgiven_5_ ///
			 rp_running_princ_bal_6_ ///
			 std_running_princ_bal_6_ act_running_princ_bal_6_ rp_interest_month_6_year_ /// 
			 std_interest_month_6_year_  act_interest_month_6_year_ rp_accum_int_month_6_year_ ///
			 std_accum_int_month_6_year_ act_accum_int_month_6_year_ rp_total_balance_6_ ///
			 std_total_balance_6_ ten_perc_6_year_ repaye_payment_month_6_year_ repaye_int_pt_6_ ///
			 repaye_minus_int_6_ repaye_princ_pt_6_ rp_interest_change_6_ std_payment_6_ ///
			 std_int_pt_6_ std_minus_int_6_ std_princ_pt_6_ std_interest_change_6_ ///
			 actual_payment_6_ actual_int_pt_6_ actual_princ_pt_6_ actual_interest_change_6_ ///
			 pts_not_equal_flag_6_ rp_post_rprinc_6_ rp_post_aint_month_6_year_ ///
			 std_post_rprinc_6_ std_post_aint_month_6_year_ act_post_rprinc_6_ ///
			 act_post_aint_month_6_year_ act_interest_forgiven_6_ ///
			 rp_running_princ_bal_7_ ///
			 std_running_princ_bal_7_ act_running_princ_bal_7_ rp_interest_month_7_year_ /// 
			 std_interest_month_7_year_  act_interest_month_7_year_ rp_accum_int_month_7_year_ ///
			 std_accum_int_month_7_year_ act_accum_int_month_7_year_ rp_total_balance_7_ ///
			 std_total_balance_7_ ten_perc_7_year_ repaye_payment_month_7_year_ repaye_int_pt_7_ ///
			 repaye_minus_int_7_ repaye_princ_pt_7_ rp_interest_change_7_ std_payment_7_ ///
			 std_int_pt_7_ std_minus_int_7_ std_princ_pt_7_ std_interest_change_7_ ///
			 actual_payment_7_ actual_int_pt_7_ actual_princ_pt_7_ actual_interest_change_7_ ///
			 pts_not_equal_flag_7_ rp_post_rprinc_7_ rp_post_aint_month_7_year_ ///
			 std_post_rprinc_7_ std_post_aint_month_7_year_ act_post_rprinc_7_ ///
			 act_post_aint_month_7_year_ act_interest_forgiven_7_ ///
			 rp_running_princ_bal_8_ ///
			 std_running_princ_bal_8_ act_running_princ_bal_8_ rp_interest_month_8_year_ /// 
			 std_interest_month_8_year_  act_interest_month_8_year_ rp_accum_int_month_8_year_ ///
			 std_accum_int_month_8_year_ act_accum_int_month_8_year_ rp_total_balance_8_ ///
			 std_total_balance_8_ ten_perc_8_year_ repaye_payment_month_8_year_ repaye_int_pt_8_ ///
			 repaye_minus_int_8_ repaye_princ_pt_8_ rp_interest_change_8_ std_payment_8_ ///
			 std_int_pt_8_ std_minus_int_8_ std_princ_pt_8_ std_interest_change_8_ ///
			 actual_payment_8_ actual_int_pt_8_ actual_princ_pt_8_ actual_interest_change_8_ ///
			 pts_not_equal_flag_8_ rp_post_rprinc_8_ rp_post_aint_month_8_year_ ///
			 std_post_rprinc_8_ std_post_aint_month_8_year_ act_post_rprinc_8_ ///
			 act_post_aint_month_8_year_ act_interest_forgiven_8_ ///
			 rp_running_princ_bal_9_ ///
			 std_running_princ_bal_9_ act_running_princ_bal_9_ rp_interest_month_9_year_ /// 
			 std_interest_month_9_year_  act_interest_month_9_year_ rp_accum_int_month_9_year_ ///
			 std_accum_int_month_9_year_ act_accum_int_month_9_year_ rp_total_balance_9_ ///
			 std_total_balance_9_ ten_perc_9_year_ repaye_payment_month_9_year_ repaye_int_pt_9_ ///
			 repaye_minus_int_9_ repaye_princ_pt_9_ rp_interest_change_9_ std_payment_9_ ///
			 std_int_pt_9_ std_minus_int_9_ std_princ_pt_9_ std_interest_change_9_ ///
			 actual_payment_9_ actual_int_pt_9_ actual_princ_pt_9_ actual_interest_change_9_ ///
			 pts_not_equal_flag_9_ rp_post_rprinc_9_ rp_post_aint_month_9_year_ ///
			 std_post_rprinc_9_ std_post_aint_month_9_year_ act_post_rprinc_9_ ///
			 act_post_aint_month_9_year_ act_interest_forgiven_9_ ///
			 rp_running_princ_bal_10_ ///
			 std_running_princ_bal_10_ act_running_princ_bal_10_ rp_interest_month_10_year_ /// 
			 std_interest_month_10_year_  act_interest_month_10_year_ rp_accum_int_month_10_year_ ///
			 std_accum_int_month_10_year_ act_accum_int_month_10_year_ rp_total_balance_10_ ///
			 std_total_balance_10_ ten_perc_10_year_ repaye_payment_month_10_year_ repaye_int_pt_10_ ///
			 repaye_minus_int_10_ repaye_princ_pt_10_ rp_interest_change_10_ std_payment_10_ ///
			 std_int_pt_10_ std_minus_int_10_ std_princ_pt_10_ std_interest_change_10_ ///
			 actual_payment_10_ actual_int_pt_10_ actual_princ_pt_10_ actual_interest_change_10_ ///
			 pts_not_equal_flag_10_ rp_post_rprinc_10_ rp_post_aint_month_10_year_ ///
			 std_post_rprinc_10_ std_post_aint_month_10_year_ act_post_rprinc_10_ ///
			 act_post_aint_month_10_year_ act_interest_forgiven_10_ ///
			 rp_running_princ_bal_11_ ///
			 std_running_princ_bal_11_ act_running_princ_bal_11_ rp_interest_month_11_year_ /// 
			 std_interest_month_11_year_  act_interest_month_11_year_ rp_accum_int_month_11_year_ ///
			 std_accum_int_month_11_year_ act_accum_int_month_11_year_ rp_total_balance_11_ ///
			 std_total_balance_11_ ten_perc_11_year_ repaye_payment_month_11_year_ repaye_int_pt_11_ ///
			 repaye_minus_int_11_ repaye_princ_pt_11_ rp_interest_change_11_ std_payment_11_ ///
			 std_int_pt_11_ std_minus_int_11_ std_princ_pt_11_ std_interest_change_11_ ///
			 actual_payment_11_ actual_int_pt_11_ actual_princ_pt_11_ actual_interest_change_11_ ///
			 pts_not_equal_flag_11_ rp_post_rprinc_11_ rp_post_aint_month_11_year_ ///
			 std_post_rprinc_11_ std_post_aint_month_11_year_ act_post_rprinc_11_ ///
			 act_post_aint_month_11_year_ act_interest_forgiven_11_ ///
			 rp_running_princ_bal_12_ ///
			 std_running_princ_bal_12_ act_running_princ_bal_12_ rp_interest_month_12_year_ /// 
			 std_interest_month_12_year_  act_interest_month_12_year_ rp_accum_int_month_12_year_ ///
			 std_accum_int_month_12_year_ act_accum_int_month_12_year_ rp_total_balance_12_ ///
			 std_total_balance_12_ ten_perc_12_year_ repaye_payment_month_12_year_ repaye_int_pt_12_ ///
			 repaye_minus_int_12_ repaye_princ_pt_12_ rp_interest_change_12_ std_payment_12_ ///
			 std_int_pt_12_ std_minus_int_12_ std_princ_pt_12_ std_interest_change_12_ ///
			 actual_payment_12_ actual_int_pt_12_ actual_princ_pt_12_ actual_interest_change_12_ ///
			 pts_not_equal_flag_12_ rp_post_rprinc_12_ rp_post_aint_month_12_year_ ///
			 std_post_rprinc_12_ std_post_aint_month_12_year_ act_post_rprinc_12_ ///
			 act_post_aint_month_12_year_ act_interest_forgiven_12_, i(opciplev) j(year)
		
		*Quick rename of some varaibles to make room for new panel versions
		rename med_earnings med_earnings_orig
		rename standard_payment standard_payment_orig 
		rename rp_running_princ_bal rp_running_princ_bal_orig
		rename std_running_princ_bal std_running_princ_bal_orig
		rename act_running_princ_bal act_running_princ_bal_orig
	
		*Rename all these variables to drop the _year suffix 
		rename (earnings_year_ disc_med_earn_year_ ///
			 rp_running_princ_bal_1_ ///
			 std_running_princ_bal_1_ act_running_princ_bal_1_ rp_interest_month_1_year_ /// 
			 std_interest_month_1_year_  act_interest_month_1_year_ rp_accum_int_month_1_year_ ///
			 std_accum_int_month_1_year_ act_accum_int_month_1_year_ rp_total_balance_1_ ///
			 std_total_balance_1_ ten_perc_1_year_ repaye_payment_month_1_year_ repaye_int_pt_1_ ///
			 repaye_minus_int_1_ repaye_princ_pt_1_ rp_interest_change_1_ std_payment_1_ ///
			 std_int_pt_1_ std_minus_int_1_ std_princ_pt_1_ std_interest_change_1_ ///
			 actual_payment_1_ actual_int_pt_1_ actual_princ_pt_1_ actual_interest_change_1_ ///
			 pts_not_equal_flag_1_ rp_post_rprinc_1_ rp_post_aint_month_1_year_ ///
			 std_post_rprinc_1_ std_post_aint_month_1_year_ act_post_rprinc_1_ ///
			 act_post_aint_month_1_year_ act_interest_forgiven_1_ ///
			 rp_running_princ_bal_2_ ///
			 std_running_princ_bal_2_ act_running_princ_bal_2_ rp_interest_month_2_year_ /// 
			 std_interest_month_2_year_  act_interest_month_2_year_ rp_accum_int_month_2_year_ ///
			 std_accum_int_month_2_year_ act_accum_int_month_2_year_ rp_total_balance_2_ ///
			 std_total_balance_2_ ten_perc_2_year_ repaye_payment_month_2_year_ repaye_int_pt_2_ ///
			 repaye_minus_int_2_ repaye_princ_pt_2_ rp_interest_change_2_ std_payment_2_ ///
			 std_int_pt_2_ std_minus_int_2_ std_princ_pt_2_ std_interest_change_2_ ///
			 actual_payment_2_ actual_int_pt_2_ actual_princ_pt_2_ actual_interest_change_2_ ///
			 pts_not_equal_flag_2_ rp_post_rprinc_2_ rp_post_aint_month_2_year_ ///
			 std_post_rprinc_2_ std_post_aint_month_2_year_ act_post_rprinc_2_ ///
			 act_post_aint_month_2_year_ act_interest_forgiven_2_ ///
			 rp_running_princ_bal_3_ ///
			 std_running_princ_bal_3_ act_running_princ_bal_3_ rp_interest_month_3_year_ /// 
			 std_interest_month_3_year_  act_interest_month_3_year_ rp_accum_int_month_3_year_ ///
			 std_accum_int_month_3_year_ act_accum_int_month_3_year_ rp_total_balance_3_ ///
			 std_total_balance_3_ ten_perc_3_year_ repaye_payment_month_3_year_ repaye_int_pt_3_ ///
			 repaye_minus_int_3_ repaye_princ_pt_3_ rp_interest_change_3_ std_payment_3_ ///
			 std_int_pt_3_ std_minus_int_3_ std_princ_pt_3_ std_interest_change_3_ ///
			 actual_payment_3_ actual_int_pt_3_ actual_princ_pt_3_ actual_interest_change_3_ ///
			 pts_not_equal_flag_3_ rp_post_rprinc_3_ rp_post_aint_month_3_year_ ///
			 std_post_rprinc_3_ std_post_aint_month_3_year_ act_post_rprinc_3_ ///
			 act_post_aint_month_3_year_ act_interest_forgiven_3_ ///
			 rp_running_princ_bal_4_ ///
			 std_running_princ_bal_4_ act_running_princ_bal_4_ rp_interest_month_4_year_ /// 
			 std_interest_month_4_year_  act_interest_month_4_year_ rp_accum_int_month_4_year_ ///
			 std_accum_int_month_4_year_ act_accum_int_month_4_year_ rp_total_balance_4_ ///
			 std_total_balance_4_ ten_perc_4_year_ repaye_payment_month_4_year_ repaye_int_pt_4_ ///
			 repaye_minus_int_4_ repaye_princ_pt_4_ rp_interest_change_4_ std_payment_4_ ///
			 std_int_pt_4_ std_minus_int_4_ std_princ_pt_4_ std_interest_change_4_ ///
			 actual_payment_4_ actual_int_pt_4_ actual_princ_pt_4_ actual_interest_change_4_ ///
			 pts_not_equal_flag_4_ rp_post_rprinc_4_ rp_post_aint_month_4_year_ ///
			 std_post_rprinc_4_ std_post_aint_month_4_year_ act_post_rprinc_4_ ///
			 act_post_aint_month_4_year_ act_interest_forgiven_4_ ///
			 rp_running_princ_bal_5_ ///
			 std_running_princ_bal_5_ act_running_princ_bal_5_ rp_interest_month_5_year_ /// 
			 std_interest_month_5_year_  act_interest_month_5_year_ rp_accum_int_month_5_year_ ///
			 std_accum_int_month_5_year_ act_accum_int_month_5_year_ rp_total_balance_5_ ///
			 std_total_balance_5_ ten_perc_5_year_ repaye_payment_month_5_year_ repaye_int_pt_5_ ///
			 repaye_minus_int_5_ repaye_princ_pt_5_ rp_interest_change_5_ std_payment_5_ ///
			 std_int_pt_5_ std_minus_int_5_ std_princ_pt_5_ std_interest_change_5_ ///
			 actual_payment_5_ actual_int_pt_5_ actual_princ_pt_5_ actual_interest_change_5_ ///
			 pts_not_equal_flag_5_ rp_post_rprinc_5_ rp_post_aint_month_5_year_ ///
			 std_post_rprinc_5_ std_post_aint_month_5_year_ act_post_rprinc_5_ ///
			 act_post_aint_month_5_year_ act_interest_forgiven_5_ ///
			 rp_running_princ_bal_6_ ///
			 std_running_princ_bal_6_ act_running_princ_bal_6_ rp_interest_month_6_year_ /// 
			 std_interest_month_6_year_  act_interest_month_6_year_ rp_accum_int_month_6_year_ ///
			 std_accum_int_month_6_year_ act_accum_int_month_6_year_ rp_total_balance_6_ ///
			 std_total_balance_6_ ten_perc_6_year_ repaye_payment_month_6_year_ repaye_int_pt_6_ ///
			 repaye_minus_int_6_ repaye_princ_pt_6_ rp_interest_change_6_ std_payment_6_ ///
			 std_int_pt_6_ std_minus_int_6_ std_princ_pt_6_ std_interest_change_6_ ///
			 actual_payment_6_ actual_int_pt_6_ actual_princ_pt_6_ actual_interest_change_6_ ///
			 pts_not_equal_flag_6_ rp_post_rprinc_6_ rp_post_aint_month_6_year_ ///
			 std_post_rprinc_6_ std_post_aint_month_6_year_ act_post_rprinc_6_ ///
			 act_post_aint_month_6_year_ act_interest_forgiven_6_ ///
			 rp_running_princ_bal_7_ ///
			 std_running_princ_bal_7_ act_running_princ_bal_7_ rp_interest_month_7_year_ /// 
			 std_interest_month_7_year_  act_interest_month_7_year_ rp_accum_int_month_7_year_ ///
			 std_accum_int_month_7_year_ act_accum_int_month_7_year_ rp_total_balance_7_ ///
			 std_total_balance_7_ ten_perc_7_year_ repaye_payment_month_7_year_ repaye_int_pt_7_ ///
			 repaye_minus_int_7_ repaye_princ_pt_7_ rp_interest_change_7_ std_payment_7_ ///
			 std_int_pt_7_ std_minus_int_7_ std_princ_pt_7_ std_interest_change_7_ ///
			 actual_payment_7_ actual_int_pt_7_ actual_princ_pt_7_ actual_interest_change_7_ ///
			 pts_not_equal_flag_7_ rp_post_rprinc_7_ rp_post_aint_month_7_year_ ///
			 std_post_rprinc_7_ std_post_aint_month_7_year_ act_post_rprinc_7_ ///
			 act_post_aint_month_7_year_ act_interest_forgiven_7_ ///
			 rp_running_princ_bal_8_ ///
			 std_running_princ_bal_8_ act_running_princ_bal_8_ rp_interest_month_8_year_ /// 
			 std_interest_month_8_year_  act_interest_month_8_year_ rp_accum_int_month_8_year_ ///
			 std_accum_int_month_8_year_ act_accum_int_month_8_year_ rp_total_balance_8_ ///
			 std_total_balance_8_ ten_perc_8_year_ repaye_payment_month_8_year_ repaye_int_pt_8_ ///
			 repaye_minus_int_8_ repaye_princ_pt_8_ rp_interest_change_8_ std_payment_8_ ///
			 std_int_pt_8_ std_minus_int_8_ std_princ_pt_8_ std_interest_change_8_ ///
			 actual_payment_8_ actual_int_pt_8_ actual_princ_pt_8_ actual_interest_change_8_ ///
			 pts_not_equal_flag_8_ rp_post_rprinc_8_ rp_post_aint_month_8_year_ ///
			 std_post_rprinc_8_ std_post_aint_month_8_year_ act_post_rprinc_8_ ///
			 act_post_aint_month_8_year_ act_interest_forgiven_8_ ///
			 rp_running_princ_bal_9_ ///
			 std_running_princ_bal_9_ act_running_princ_bal_9_ rp_interest_month_9_year_ /// 
			 std_interest_month_9_year_  act_interest_month_9_year_ rp_accum_int_month_9_year_ ///
			 std_accum_int_month_9_year_ act_accum_int_month_9_year_ rp_total_balance_9_ ///
			 std_total_balance_9_ ten_perc_9_year_ repaye_payment_month_9_year_ repaye_int_pt_9_ ///
			 repaye_minus_int_9_ repaye_princ_pt_9_ rp_interest_change_9_ std_payment_9_ ///
			 std_int_pt_9_ std_minus_int_9_ std_princ_pt_9_ std_interest_change_9_ ///
			 actual_payment_9_ actual_int_pt_9_ actual_princ_pt_9_ actual_interest_change_9_ ///
			 pts_not_equal_flag_9_ rp_post_rprinc_9_ rp_post_aint_month_9_year_ ///
			 std_post_rprinc_9_ std_post_aint_month_9_year_ act_post_rprinc_9_ ///
			 act_post_aint_month_9_year_ act_interest_forgiven_9_ ///
			 rp_running_princ_bal_10_ ///
			 std_running_princ_bal_10_ act_running_princ_bal_10_ rp_interest_month_10_year_ /// 
			 std_interest_month_10_year_  act_interest_month_10_year_ rp_accum_int_month_10_year_ ///
			 std_accum_int_month_10_year_ act_accum_int_month_10_year_ rp_total_balance_10_ ///
			 std_total_balance_10_ ten_perc_10_year_ repaye_payment_month_10_year_ repaye_int_pt_10_ ///
			 repaye_minus_int_10_ repaye_princ_pt_10_ rp_interest_change_10_ std_payment_10_ ///
			 std_int_pt_10_ std_minus_int_10_ std_princ_pt_10_ std_interest_change_10_ ///
			 actual_payment_10_ actual_int_pt_10_ actual_princ_pt_10_ actual_interest_change_10_ ///
			 pts_not_equal_flag_10_ rp_post_rprinc_10_ rp_post_aint_month_10_year_ ///
			 std_post_rprinc_10_ std_post_aint_month_10_year_ act_post_rprinc_10_ ///
			 act_post_aint_month_10_year_ act_interest_forgiven_10_ ///
			 rp_running_princ_bal_11_ ///
			 std_running_princ_bal_11_ act_running_princ_bal_11_ rp_interest_month_11_year_ /// 
			 std_interest_month_11_year_  act_interest_month_11_year_ rp_accum_int_month_11_year_ ///
			 std_accum_int_month_11_year_ act_accum_int_month_11_year_ rp_total_balance_11_ ///
			 std_total_balance_11_ ten_perc_11_year_ repaye_payment_month_11_year_ repaye_int_pt_11_ ///
			 repaye_minus_int_11_ repaye_princ_pt_11_ rp_interest_change_11_ std_payment_11_ ///
			 std_int_pt_11_ std_minus_int_11_ std_princ_pt_11_ std_interest_change_11_ ///
			 actual_payment_11_ actual_int_pt_11_ actual_princ_pt_11_ actual_interest_change_11_ ///
			 pts_not_equal_flag_11_ rp_post_rprinc_11_ rp_post_aint_month_11_year_ ///
			 std_post_rprinc_11_ std_post_aint_month_11_year_ act_post_rprinc_11_ ///
			 act_post_aint_month_11_year_ act_interest_forgiven_11_ ///
			 rp_running_princ_bal_12_ ///
			 std_running_princ_bal_12_ act_running_princ_bal_12_ rp_interest_month_12_year_ /// 
			 std_interest_month_12_year_  act_interest_month_12_year_ rp_accum_int_month_12_year_ ///
			 std_accum_int_month_12_year_ act_accum_int_month_12_year_ rp_total_balance_12_ ///
			 std_total_balance_12_ ten_perc_12_year_ repaye_payment_month_12_year_ repaye_int_pt_12_ ///
			 repaye_minus_int_12_ repaye_princ_pt_12_ rp_interest_change_12_ std_payment_12_ ///
			 std_int_pt_12_ std_minus_int_12_ std_princ_pt_12_ std_interest_change_12_ ///
			 actual_payment_12_ actual_int_pt_12_ actual_princ_pt_12_ actual_interest_change_12_ ///
			 pts_not_equal_flag_12_ rp_post_rprinc_12_ rp_post_aint_month_12_year_ ///
			 std_post_rprinc_12_ std_post_aint_month_12_year_ act_post_rprinc_12_ ///
			 act_post_aint_month_12_year_ act_interest_forgiven_12_) ///
			(earnings disc_med_earn ///
			 rp_running_princ_bal_1 ///
			 std_running_princ_bal_1 act_running_princ_bal_1 rp_interest_month_1 /// 
			 std_interest_month_1  act_interest_month_1 rp_accum_int_month_1 ///
			 std_accum_int_month_1 act_accum_int_month_1 rp_total_balance_1 ///
			 std_total_balance_1 ten_perc_1 repaye_payment_month_1 repaye_int_pt_1 ///
			 repaye_minus_int_1 repaye_princ_pt_1 rp_interest_change_1 std_payment_1 ///
			 std_int_pt_1 std_minus_int_1 std_princ_pt_1 std_interest_change_1 ///
			 actual_payment_1 actual_int_pt_1 actual_princ_pt_1 actual_interest_change_1 ///
			 pts_not_equal_flag_1 rp_post_rprinc_1 rp_post_aint_month_1 ///
			 std_post_rprinc_1 std_post_aint_month_1 act_post_rprinc_1 ///
			 act_post_aint_month_1 act_interest_forgiven_1 ///
			 rp_running_princ_bal_2 ///
			 std_running_princ_bal_2 act_running_princ_bal_2 rp_interest_month_2 /// 
			 std_interest_month_2  act_interest_month_2 rp_accum_int_month_2 ///
			 std_accum_int_month_2 act_accum_int_month_2 rp_total_balance_2 ///
			 std_total_balance_2 ten_perc_2 repaye_payment_month_2 repaye_int_pt_2 ///
			 repaye_minus_int_2 repaye_princ_pt_2 rp_interest_change_2 std_payment_2 ///
			 std_int_pt_2 std_minus_int_2 std_princ_pt_2 std_interest_change_2 ///
			 actual_payment_2 actual_int_pt_2 actual_princ_pt_2 actual_interest_change_2 ///
			 pts_not_equal_flag_2 rp_post_rprinc_2 rp_post_aint_month_2 ///
			 std_post_rprinc_2 std_post_aint_month_2 act_post_rprinc_2 ///
			 act_post_aint_month_2 act_interest_forgiven_2 ///
			 rp_running_princ_bal_3 ///
			 std_running_princ_bal_3 act_running_princ_bal_3 rp_interest_month_3 /// 
			 std_interest_month_3  act_interest_month_3 rp_accum_int_month_3 ///
			 std_accum_int_month_3 act_accum_int_month_3 rp_total_balance_3 ///
			 std_total_balance_3 ten_perc_3 repaye_payment_month_3 repaye_int_pt_3 ///
			 repaye_minus_int_3 repaye_princ_pt_3 rp_interest_change_3 std_payment_3 ///
			 std_int_pt_3 std_minus_int_3 std_princ_pt_3 std_interest_change_3 ///
			 actual_payment_3 actual_int_pt_3 actual_princ_pt_3 actual_interest_change_3 ///
			 pts_not_equal_flag_3 rp_post_rprinc_3 rp_post_aint_month_3 ///
			 std_post_rprinc_3 std_post_aint_month_3 act_post_rprinc_3 ///
			 act_post_aint_month_3 act_interest_forgiven_3 ///
			 rp_running_princ_bal_4 ///
			 std_running_princ_bal_4 act_running_princ_bal_4 rp_interest_month_4 /// 
			 std_interest_month_4  act_interest_month_4 rp_accum_int_month_4 ///
			 std_accum_int_month_4 act_accum_int_month_4 rp_total_balance_4 ///
			 std_total_balance_4 ten_perc_4 repaye_payment_month_4 repaye_int_pt_4 ///
			 repaye_minus_int_4 repaye_princ_pt_4 rp_interest_change_4 std_payment_4 ///
			 std_int_pt_4 std_minus_int_4 std_princ_pt_4 std_interest_change_4 ///
			 actual_payment_4 actual_int_pt_4 actual_princ_pt_4 actual_interest_change_4 ///
			 pts_not_equal_flag_4 rp_post_rprinc_4 rp_post_aint_month_4 ///
			 std_post_rprinc_4 std_post_aint_month_4 act_post_rprinc_4 ///
			 act_post_aint_month_4 act_interest_forgiven_4 ///
			 rp_running_princ_bal_5 ///
			 std_running_princ_bal_5 act_running_princ_bal_5 rp_interest_month_5 /// 
			 std_interest_month_5  act_interest_month_5 rp_accum_int_month_5 ///
			 std_accum_int_month_5 act_accum_int_month_5 rp_total_balance_5 ///
			 std_total_balance_5 ten_perc_5 repaye_payment_month_5 repaye_int_pt_5 ///
			 repaye_minus_int_5 repaye_princ_pt_5 rp_interest_change_5 std_payment_5 ///
			 std_int_pt_5 std_minus_int_5 std_princ_pt_5 std_interest_change_5 ///
			 actual_payment_5 actual_int_pt_5 actual_princ_pt_5 actual_interest_change_5 ///
			 pts_not_equal_flag_5 rp_post_rprinc_5 rp_post_aint_month_5 ///
			 std_post_rprinc_5 std_post_aint_month_5 act_post_rprinc_5 ///
			 act_post_aint_month_5 act_interest_forgiven_5 ///
			 rp_running_princ_bal_6 ///
			 std_running_princ_bal_6 act_running_princ_bal_6 rp_interest_month_6 /// 
			 std_interest_month_6  act_interest_month_6 rp_accum_int_month_6 ///
			 std_accum_int_month_6 act_accum_int_month_6 rp_total_balance_6 ///
			 std_total_balance_6 ten_perc_6 repaye_payment_month_6 repaye_int_pt_6 ///
			 repaye_minus_int_6 repaye_princ_pt_6 rp_interest_change_6 std_payment_6 ///
			 std_int_pt_6 std_minus_int_6 std_princ_pt_6 std_interest_change_6 ///
			 actual_payment_6 actual_int_pt_6 actual_princ_pt_6 actual_interest_change_6 ///
			 pts_not_equal_flag_6 rp_post_rprinc_6 rp_post_aint_month_6 ///
			 std_post_rprinc_6 std_post_aint_month_6 act_post_rprinc_6 ///
			 act_post_aint_month_6 act_interest_forgiven_6 ///
			 rp_running_princ_bal_7 ///
			 std_running_princ_bal_7 act_running_princ_bal_7 rp_interest_month_7 /// 
			 std_interest_month_7  act_interest_month_7 rp_accum_int_month_7 ///
			 std_accum_int_month_7 act_accum_int_month_7 rp_total_balance_7 ///
			 std_total_balance_7 ten_perc_7 repaye_payment_month_7 repaye_int_pt_7 ///
			 repaye_minus_int_7 repaye_princ_pt_7 rp_interest_change_7 std_payment_7 ///
			 std_int_pt_7 std_minus_int_7 std_princ_pt_7 std_interest_change_7 ///
			 actual_payment_7 actual_int_pt_7 actual_princ_pt_7 actual_interest_change_7 ///
			 pts_not_equal_flag_7 rp_post_rprinc_7 rp_post_aint_month_7 ///
			 std_post_rprinc_7 std_post_aint_month_7 act_post_rprinc_7 ///
			 act_post_aint_month_7 act_interest_forgiven_7 ///
			 rp_running_princ_bal_8 ///
			 std_running_princ_bal_8 act_running_princ_bal_8 rp_interest_month_8 /// 
			 std_interest_month_8  act_interest_month_8 rp_accum_int_month_8 ///
			 std_accum_int_month_8 act_accum_int_month_8 rp_total_balance_8 ///
			 std_total_balance_8 ten_perc_8 repaye_payment_month_8 repaye_int_pt_8 ///
			 repaye_minus_int_8 repaye_princ_pt_8 rp_interest_change_8 std_payment_8 ///
			 std_int_pt_8 std_minus_int_8 std_princ_pt_8 std_interest_change_8 ///
			 actual_payment_8 actual_int_pt_8 actual_princ_pt_8 actual_interest_change_8 ///
			 pts_not_equal_flag_8 rp_post_rprinc_8 rp_post_aint_month_8 ///
			 std_post_rprinc_8 std_post_aint_month_8 act_post_rprinc_8 ///
			 act_post_aint_month_8 act_interest_forgiven_8 ///
			 rp_running_princ_bal_9 ///
			 std_running_princ_bal_9 act_running_princ_bal_9 rp_interest_month_9 /// 
			 std_interest_month_9  act_interest_month_9 rp_accum_int_month_9 ///
			 std_accum_int_month_9 act_accum_int_month_9 rp_total_balance_9 ///
			 std_total_balance_9 ten_perc_9 repaye_payment_month_9 repaye_int_pt_9 ///
			 repaye_minus_int_9 repaye_princ_pt_9 rp_interest_change_9 std_payment_9 ///
			 std_int_pt_9 std_minus_int_9 std_princ_pt_9 std_interest_change_9 ///
			 actual_payment_9 actual_int_pt_9 actual_princ_pt_9 actual_interest_change_9 ///
			 pts_not_equal_flag_9 rp_post_rprinc_9 rp_post_aint_month_9 ///
			 std_post_rprinc_9 std_post_aint_month_9 act_post_rprinc_9 ///
			 act_post_aint_month_9 act_interest_forgiven_9 ///
			 rp_running_princ_bal_10 ///
			 std_running_princ_bal_10 act_running_princ_bal_10 rp_interest_month_10 /// 
			 std_interest_month_10  act_interest_month_10 rp_accum_int_month_10 ///
			 std_accum_int_month_10 act_accum_int_month_10 rp_total_balance_10 ///
			 std_total_balance_10 ten_perc_10 repaye_payment_month_10 repaye_int_pt_10 ///
			 repaye_minus_int_10 repaye_princ_pt_10 rp_interest_change_10 std_payment_10 ///
			 std_int_pt_10 std_minus_int_10 std_princ_pt_10 std_interest_change_10 ///
			 actual_payment_10 actual_int_pt_10 actual_princ_pt_10 actual_interest_change_10 ///
			 pts_not_equal_flag_10 rp_post_rprinc_10 rp_post_aint_month_10 ///
			 std_post_rprinc_10 std_post_aint_month_10 act_post_rprinc_10 ///
			 act_post_aint_month_10 act_interest_forgiven_10 ///
			 rp_running_princ_bal_11 ///
			 std_running_princ_bal_11 act_running_princ_bal_11 rp_interest_month_11 /// 
			 std_interest_month_11  act_interest_month_11 rp_accum_int_month_11 ///
			 std_accum_int_month_11 act_accum_int_month_11 rp_total_balance_11 ///
			 std_total_balance_11 ten_perc_11 repaye_payment_month_11 repaye_int_pt_11 ///
			 repaye_minus_int_11 repaye_princ_pt_11 rp_interest_change_11 std_payment_11 ///
			 std_int_pt_11 std_minus_int_11 std_princ_pt_11 std_interest_change_11 ///
			 actual_payment_11 actual_int_pt_11 actual_princ_pt_11 actual_interest_change_11 ///
			 pts_not_equal_flag_11 rp_post_rprinc_11 rp_post_aint_month_11 ///
			 std_post_rprinc_11 std_post_aint_month_11 act_post_rprinc_11 ///
			 act_post_aint_month_11 act_interest_forgiven_11 ///
			 rp_running_princ_bal_12 ///
			 std_running_princ_bal_12 act_running_princ_bal_12 rp_interest_month_12 /// 
			 std_interest_month_12  act_interest_month_12 rp_accum_int_month_12 ///
			 std_accum_int_month_12 act_accum_int_month_12 rp_total_balance_12 ///
			 std_total_balance_12 ten_perc_12 repaye_payment_month_12 repaye_int_pt_12 ///
			 repaye_minus_int_12 repaye_princ_pt_12 rp_interest_change_12 std_payment_12 ///
			 std_int_pt_12 std_minus_int_12 std_princ_pt_12 std_interest_change_12 ///
			 actual_payment_12 actual_int_pt_12 actual_princ_pt_12 actual_interest_change_12 ///
			 pts_not_equal_flag_12 rp_post_rprinc_12 rp_post_aint_month_12 ///
			 std_post_rprinc_12 std_post_aint_month_12 act_post_rprinc_12 ///
			 act_post_aint_month_12 act_interest_forgiven_12 )
	
		*Reshape 
		reshape long rp_running_princ_bal_ ///
			 std_running_princ_bal_ act_running_princ_bal_ rp_interest_month_ /// 
			 std_interest_month_  act_interest_month_ rp_accum_int_month_ ///
			 std_accum_int_month_ act_accum_int_month_ rp_total_balance_ ///
			 std_total_balance_ ten_perc_ repaye_payment_month_ repaye_int_pt_ ///
			 repaye_minus_int_ repaye_princ_pt_ rp_interest_change_ std_payment_ ///
			 std_int_pt_ std_minus_int_ std_princ_pt_ std_interest_change_ ///
			 actual_payment_ actual_int_pt_ actual_princ_pt_ actual_interest_change_ ///
			 pts_not_equal_flag_ rp_post_rprinc_ rp_post_aint_month_ ///
			 std_post_rprinc_ std_post_aint_month_ act_post_rprinc_ ///
			 act_post_aint_month_ act_interest_forgiven_, i(opciplev year) j(month) 
	
		*Rename variabes to drop _month suffix
		rename (rp_running_princ_bal_ ///
			 std_running_princ_bal_ act_running_princ_bal_ rp_interest_month_ /// 
			 std_interest_month_  act_interest_month_ rp_accum_int_month_ ///
			 std_accum_int_month_ act_accum_int_month_ rp_total_balance_ ///
			 std_total_balance_ ten_perc_ repaye_payment_month_ repaye_int_pt_ ///
			 repaye_minus_int_ repaye_princ_pt_ rp_interest_change_ std_payment_ ///
			 std_int_pt_ std_minus_int_ std_princ_pt_ std_interest_change_ ///
			 actual_payment_ actual_int_pt_ actual_princ_pt_ actual_interest_change_ ///
			 pts_not_equal_flag_ rp_post_rprinc_ rp_post_aint_month_ ///
			 std_post_rprinc_ std_post_aint_month_ act_post_rprinc_ ///
			 act_post_aint_month_ act_interest_forgiven_)  ///
			(rp_running_princ_bal ///
			 std_running_princ_bal act_running_princ_bal rp_interest /// 
			 std_interest  act_interest rp_accum_int ///
			 std_accum_int act_accum_int rp_total_balance ///
			 std_total_balance ten_perc repaye_payment repaye_int_pt ///
			 repaye_minus_int repaye_princ_pt rp_interest_change std_payment ///
			 std_int_pt std_minus_int std_princ_pt std_interest_change ///
			 actual_payment actual_int_pt actual_princ_pt actual_interest_change ///
			 pts_not_equal_flag rp_post_rprinc rp_post_aint ///
			 std_post_rprinc std_post_aint act_post_rprinc ///
			 act_post_aint act_interest_forgiven)
		
		destring level_code, replace 
		
		*Save this for the grad data only
		saveold "${ge_data}loan_dynamics_calcs_long_nongrad.dta", replace 
		
		
		
